%% Gilles Antoniazza / June 2020

clear all
close all

% Kinetic energy of each category of weight/height 
Ec = [0.0064 0.0139 0.0275 0.0488 0.1111 0.2323 0.4574 0.8905 1.0639]; % Kinectic energy (from high speed camera data): Ec = 0.5 * mass [kg] * velocity^2 [m/s]

%Labor - data
all_maxs_labor = cell2mat(struct2cell(load('all_maxs_labor.mat')));      
all_means_labor = cell2mat(struct2cell(load('all_means_labor.mat'))); 
all_std_labor = cell2mat(struct2cell(load('all_std_labor.mat')));
all_en_labor = cell2mat(struct2cell(load('all_enc_labor.mat')));

%Labor - regression line
len_labor = log(Ec);
lmax_labor = log(all_means_labor);
p_labor=polyfit(len_labor,lmax_labor,1);
x_fitline_labor = len_labor;
y_fitline_labor = p_labor(1)*x_fitline_labor+p_labor(2);
x_fitlog_labor = exp(x_fitline_labor);
y_fitlog_labor = exp(y_fitline_labor);
yfit_labor = polyval(p_labor,len_labor);
yresid_labor = lmax_labor - yfit_labor;
SSresid_labor = sum(yresid_labor.^2);
SStotal_labor = (length(len_labor)-1) * var(len_labor);
rsq_labor = 1 - SSresid_labor/SStotal_labor;


%% Figure 3

figure
set(gca, 'XScale', 'log')
set(gca, 'YScale', 'log')
loglog(x_fitlog_labor,y_fitlog_labor,'Linewidth',2,'Color',[236 112 99]./255,'Linewidth',2)
hold on
hold on
loglog(Ec,all_means_labor,'o','Color',[236 112 99]./255,'Markersize',10,'Linewidth',2)
hold on 
errorbar(Ec,all_means_labor,all_std_labor,'vertical','+','Color',[236 112 99]./255, 'Linewidth',2)
grid on
ax = gca
ax.GridLineStyle = '-'
ax.GridColor = 'k'
ax.GridAlpha = 0.5 % maximum line opacity
ax.MinorGridLineStyle = ':'
ax.MinorGridAlpha = 1
box off
xlabel('Kinetic energy [J]');
xticklabels({'0.01','0.1','1'})
yticklabels({'0.01','0.1','1','10'})
ylabel('A_m_a_x [V]')
set(gca,'FontSize',30);
% xlim([2*10^-2 5*10^0]);
% ylim([7*10^0 4*10^2]);
text(7*10^-3,7*10^0,sprintf('y_l_a_b = %.3f x^{%.3f} / R^2 = %.3f',exp(p_labor(2)),p_labor(1),rsq_labor),'Fontsize',30,'Color',[236 112 99]./255)
