%% Gilles Antoniazza / June 2020

clear all
close all

%% Kinetic energy of each category of weight/height 
Ec = [0.0064 0.0139 0.0275 0.0488 0.1111 0.2323 0.4574 0.8905 1.0639]; % Cinectic energy (High speed camera): Ec = 0.5 * mass [kg] * velocity^2 [m/s]


% Load data
Geo1 =cell2mat(struct2cell(load('geo1.mat')));       
Geo1=mat2cell(Geo1,[10],[1,1,1,1,1,1,1,1,1]);                                  
Geo2 =cell2mat(struct2cell(load('geo2.mat')));      
Geo2=mat2cell(Geo2,[10],[1,1,1,1,1,1,1,1,1]);
Geo2{1,4}(10)=[]; 
Geo3 =cell2mat(struct2cell(load('geo3.mat')));       
Geo3=mat2cell(Geo3,[10],[1,1,1,1,1,1,1,1,1]);
Geo4 =cell2mat(struct2cell(load('geo4.mat')));       
Geo4=mat2cell(Geo4,[10],[1,1,1,1,1,1,1,1,1]);                               
Geo5 =cell2mat(struct2cell(load('geo5.mat')));       
Geo5=mat2cell(Geo5,[10],[1,1,1,1,1,1,1,1,1]);
Geo6 =cell2mat(struct2cell(load('geo6.mat')));       
Geo6=mat2cell(Geo6,[10],[1,1,1,1,1,1,1,1,1]);                                   
Geo7 =cell2mat(struct2cell(load('geo7.mat')));       
Geo7=mat2cell(Geo7,[10],[1,1,1,1,1,1,1,1,1]);

%% Figure 5d

Geos = {Geo1',Geo2',Geo3',Geo4',Geo5',Geo6',Geo7'};

for i = 1:7;
    temp = Geos{1,i};
    all_maxs_geos(:,i) = {vertcat(temp{1:9,1})};
    for j = 1:9;
      Mean_geos(j,i) = mean(temp{j,1});
      Std_geos(j,i) = std(temp{j,1});
      all_ec_geos(j,i) = {ones(length(temp{j,1}),1) .* Ec(j)};
    end
    all_Ec_geos(:,i)= {vertcat(all_ec_geos{1:9,i})};    
end

for i = 1:7;   
% len = log(all_Ec_geos{1,i});
len = log(Ec');
% lmax = log(all_maxs_geos{1,i});
lmax = log(Mean_geos(:,i));
p_geos(i)={polyfit(len,lmax,1)};
p=polyfit(len,lmax,1);
x_fitline = len;
y_fitline = p(1)*x_fitline+p(2);
x_fitlog_geos(i) = {exp(x_fitline)};
y_fitlog_geos(i) = {exp(y_fitline)};
yfit = polyval(p,len);
yresid = lmax - yfit;
SSresid = sum(yresid.^2);
SStotal = (length(len)-1) * var(len);
rsq_geos(i) = {1 - SSresid/SStotal};
end

figure
set(gca, 'XScale', 'log')
set(gca, 'YScale', 'log')
length = 7;
light = [244, 236, 247]/255;
dark = [74, 35, 90]/255;
colors_p = [linspace(light(1),dark(1),length)', linspace(light(2),dark(2),length)', linspace(light(3),dark(3),length)'];
for i=1:7;
    h1 =loglog(x_fitlog_geos{1,i},y_fitlog_geos{1,i},'Linewidth',2,'Color',colors_p(i,:))
    hold on
     h2 =loglog(Ec',Mean_geos(:,i),'o','Color',colors_p(i,:),'Markersize',10,'Linewidth',2,'HandleVisibility','off')
  hold on
end
legend('Geo1','Geo2','Geo3','Geo4','Geo5','Geo6','Geo7','Location','Southeast','FontSize',40)
legend boxoff
box off
grid on
ax = gca
ax.GridLineStyle = '-'
ax.GridColor = 'k'
ax.GridAlpha = 0.5 % maximum line opacity
ax.MinorGridLineStyle = ':'
ax.MinorGridAlpha = 1
xlabel('Kinetic energy [J]');
xticklabels({'0.01','0.1','1'})
yticklabels({'0.01','0.1','1','10'})
ylim([0.01 10]);
ylabel('A_m_a_x [V]')
set(gca,'FontSize',40);

for i = 1:7;
    stats(i,1:3) = [exp(p_geos{1,i}(2)) p_geos{1,i}(1) rsq_geos{1,i}];
end

%writematrix(stats,'stats_rie.xls');

