%% Gilles Antoniazza / June 2020

clear all
close all

%% Energy of each category of weight/height 
Ec = [0.0064 0.0139 0.0275 0.0488 0.1111 0.2323 0.4574 0.8905 1.0639]; % Kinectic energy (measured from high speed camera data): Ec = 0.5 * mass [kg] * velocity^2 [m/s]

% Labor
all_means_lab = cell2mat(struct2cell(load('all_means_labor.mat'))); 
all_std_lab = cell2mat(struct2cell(load('all_std_labor.mat')));
all_imps_means_lab = cell2mat(struct2cell(load('all_imps_means_labor.mat')));

% Vallon de Nant
all_means_adn = cell2mat(struct2cell(load('all_means_VDN.mat'))); 
all_std_adn = cell2mat(struct2cell(load('all_std_VDN.mat')));
all_imps_means_adn = cell2mat(struct2cell(load('all_imps_means_VDN.mat')));
all_imps_std_adn = cell2mat(struct2cell(load('all_imps_std_VDN.mat')));

%Albula
all_means_alb = cell2mat(struct2cell(load('all_means_Alb.mat'))); 
all_std_alb = cell2mat(struct2cell(load('all_std_Alb.mat')));
all_imps_means_alb = cell2mat(struct2cell(load('all_imps_means_alb.mat')));
all_imps_std_alb = cell2mat(struct2cell(load('all_imps_std_alb.mat')));

%Naviscence     
all_means_nav = cell2mat(struct2cell(load('all_means_Nav.mat'))); 
all_std_nav = cell2mat(struct2cell(load('all_std_Nav.mat')));
all_imps_means_nav = cell2mat(struct2cell(load('all_imps_means_Nav.mat')));
all_imps_std_nav = cell2mat(struct2cell(load('all_imps_std_Nav.mat')));

%Riedbach
all_means_rie = cell2mat(struct2cell(load('all_means_Ried.mat'))); 
all_std_rie = cell2mat(struct2cell(load('all_std_Ried.mat')));
all_imps_means_rie = cell2mat(struct2cell(load('all_imps_means_Ried.mat')));

%% Regressions

%Labor
limp = log(all_imps_means_lab(4:end));
lmax = log(all_means_lab(4:end));
p_lab=polyfit(lmax,limp,1);
x_fitline = lmax;
y_fitline = p_lab(1)*x_fitline+p_lab(2);
x_fitlog_lab = exp(x_fitline);
y_fitlog_lab = exp(y_fitline);
yfit = polyval(p_lab,lmax);
yresid = limp - yfit;
SSresid = sum(yresid.^2);
SStotal = (length(lmax)-1) * var(lmax);
rsq_lab = 1 - SSresid/SStotal;

%Avanon
limp = log(all_imps_means_adn(4:end));
lmax = log(all_means_adn(4:end));
p_adn=polyfit(lmax,limp,1);
x_fitline = lmax;
y_fitline = p_adn(1)*x_fitline+p_adn(2);
x_fitlog_adn = exp(x_fitline);
y_fitlog_adn = exp(y_fitline);
yfit = polyval(p_adn,lmax);
yresid = limp - yfit;
SSresid = sum(yresid.^2);
SStotal = (length(lmax)-1) * var(lmax);
rsq_adn = 1 - SSresid/SStotal;

%Albula
limp = log(all_imps_means_alb(4:end));
lmax = log(all_means_alb(4:end));
p_alb=polyfit(lmax,limp,1);
x_fitline = lmax;
y_fitline = p_alb(1)*x_fitline+p_alb(2);
x_fitlog_alb = exp(x_fitline);
y_fitlog_alb = exp(y_fitline);
yfit = polyval(p_alb,lmax);
yresid = limp - yfit;
SSresid = sum(yresid.^2);
SStotal = (length(lmax)-1) * var(lmax);
rsq_alb = 1 - SSresid/SStotal;

%Naviscence
limp = log(all_imps_means_nav(4:end));
lmax = log(all_means_nav(4:end));
p_nav=polyfit(lmax,limp,1);
x_fitline = lmax;
y_fitline = p_nav(1)*x_fitline+p_nav(2);
x_fitlog_nav = exp(x_fitline);
y_fitlog_nav = exp(y_fitline);
yfit = polyval(p_nav,lmax);
yresid = limp - yfit;
SSresid = sum(yresid.^2);
SStotal = (length(lmax)-1) * var(lmax);
rsq_nav = 1 - SSresid/SStotal;

%Riedbach
limp = log(all_imps_means_rie(4:end));
lmax = log(all_means_rie(4:end));
p_rie=polyfit(lmax,limp,1);
x_fitline = lmax;
y_fitline = p_rie(1)*x_fitline+p_rie(2);
x_fitlog_rie = exp(x_fitline);
y_fitlog_rie = exp(y_fitline);
yfit = polyval(p_rie,lmax);
yresid = limp - yfit;
SSresid = sum(yresid.^2);
SStotal = (length(lmax)-1) * var(lmax);
rsq_rie = 1 - SSresid/SStotal;


%% Figure S2

sensors_adn = 10;
light = [235, 245, 251]/255;
dark = [27, 79, 144]/255;
colors_p_adn = [linspace(light(1),dark(1),sensors_adn)', linspace(light(2),dark(2),sensors_adn)', linspace(light(3),dark(3),sensors_adn)'];

sensors_nav = 12;
light = [233, 247, 239]/255;
dark = [20, 90, 50]/255;
colors_p_nav = [linspace(light(1),dark(1),sensors_nav)', linspace(light(2),dark(2),sensors_nav)', linspace(light(3),dark(3),sensors_nav)'];

sensors = 14;
light = [251, 238, 230]/255;
dark = [110, 44, 0]/255;
colors_p_alb = [linspace(light(1),dark(1),sensors)', linspace(light(2),dark(2),sensors)', linspace(light(3),dark(3),sensors)'];


figure
set(gca, 'XScale', 'log')
set(gca, 'YScale', 'log')

% loglog(x_fitlog_lab,y_fitlog_lab,'Linewidth',2,'Color',[236 112 99]./255,'Linewidth',2)
% hold on
loglog(x_fitlog_adn,y_fitlog_adn,'Linewidth',2,'Color',colors_p_adn(10,:),'Linewidth',2)
hold on
loglog(x_fitlog_alb,y_fitlog_alb,'Linewidth',2,'Color',colors_p_alb(14,:),'Linewidth',2)
hold on
loglog(x_fitlog_nav,y_fitlog_nav,'Linewidth',2,'Color',colors_p_nav(12,:),'Linewidth',2)
% hold on
% loglog(x_fitlog_rie,y_fitlog_rie,'Linewidth',2,'Color',[165 105 189]./255,'Linewidth',2)

% hold on
% loglog(all_imps_means_lab(4:end),all_means_lab(4:end),'o','Color',[236 112 99]./255,'Markersize',10,'Linewidth',2)
hold on
loglog(all_means_adn(4:end),all_imps_means_adn(4:end),'o','Color',colors_p_adn(10,:),'Markersize',10,'Linewidth',2)
hold on
loglog(all_means_alb(4:end),all_imps_means_alb(4:end),'o','Color',colors_p_alb(14,:),'Markersize',10,'Linewidth',2)
hold on
loglog(all_means_nav(4:end),all_imps_means_nav(4:end),'o','Color',colors_p_nav(12,:),'Markersize',10,'Linewidth',2)
% hold on
% loglog(all_imps_means_rie(4:end),all_means_rie(4:end),'o','Color',[165 105 189]./255,'Markersize',10,'Linewidth',2)

% hold on 
% errorbar(all_imps_means_lab(4:end),all_means_lab(4:end),all_std_lab(4:end),'vertical','+','Color',[236 112 99]./255, 'Linewidth',2)
hold on
errorbar(all_means_adn(4:end),all_imps_means_adn(4:end),all_std_adn(4:end),'horizontal','+','Color',colors_p_adn(3,:), 'Linewidth',1)
hold on
errorbar(all_means_alb(4:end),all_imps_means_alb(4:end),all_std_alb(4:end),'horizontal','+','Color',colors_p_alb(3,:), 'Linewidth',1)
hold on
errorbar(all_means_nav(4:end),all_imps_means_nav(4:end),all_std_nav(4:end),'horizontal','+','Color',colors_p_nav(3,:), 'Linewidth',1)
% hold on
% errorbar(all_imps_means_rie(4:end),all_means_rie(4:end),all_std_rie(4:end),'vertical','+','Color',[165 105 189]./255, 'Linewidth',2)

% hold on 
% errorbar(all_imps_means_lab(4:end),all_means_lab(4:end),all_std_lab(4:end),'vertical','+','Color',[236 112 99]./255, 'Linewidth',2)
hold on
errorbar(all_means_adn(4:end),all_imps_means_adn(4:end),all_imps_std_adn(4:end),'vertical','+','Color',colors_p_adn(3,:), 'Linewidth',1)
hold on
errorbar(all_means_alb(4:end),all_imps_std_alb(4:end),all_imps_means_alb(4:end),'vertical','+','Color',colors_p_alb(3,:), 'Linewidth',1)
hold on
errorbar(all_means_nav(4:end),all_imps_means_nav(4:end),all_imps_std_nav(4:end),'vertical','+','Color',colors_p_nav(3,:), 'Linewidth',1)
% hold on
% errorbar(all_imps_means_rie(4:end),all_means_rie(4:end),all_std_rie(4:end),'vertical','+','Color',[165 105 189]./255, 'Linewidth',2)

box on
grid on
ylabel('N_i_m_p (> 0.1 V) [-]')
xlabel('A_m_a_x [V]');
yticks([1 5 10]);
yticklabels({'1','5','10'})
xticklabels({'0.1','1','10'})
set(gca,'FontSize',40);
xlim([1*10^-1 1*10^1]);
ax = gca
ax.GridLineStyle = '-'
ax.GridColor = 'k'
ax.GridAlpha = 0.5 % maximum line opacity
ax.MinorGridLineStyle = ':'
ax.MinorGridAlpha = 0.1

%text(10*10^0,1*10^0,sprintf('y_l_a_b = %.3f x^{%.3f} / R^2 = %.3f',exp(p_lab(2)),p_lab(1),rsq_lab),'Fontsize',30,'Color',[236 112 99]./255);
text(2*10^0,2*10^0,sprintf('y_a_d_n = %.3f x^{%.3f}',exp(p_adn(2)),p_adn(1)),'Fontsize',40,'Color',colors_p_adn(10,:));
text(2*10^0,1.5*10^0,sprintf('y_a_l_b = %.3f x^{%.3f}',exp(p_alb(2)),p_alb(1)),'Fontsize',40,'Color',colors_p_alb(14,:));
text(2*10^0,1.1*10^0,sprintf('y_n_a_v = %.3f x^{%.3f}',exp(p_nav(2)),p_nav(1)),'Fontsize',40,'Color',colors_p_nav(12,:));
%text(2*10^0,9*10^0,sprintf('y_r_i_e = %.3f x^{%.3f} / R^2 = %.3f',exp(p_rie(2)),p_rie(1),rsq_rie),'Fontsize',30,'Color',[165 105 189]./255);
