%% Gilles Antoniazza / June 2020

clear all
close all

%% Comparison interstation
%% Kinetic energy of each category of weight/height 
Ec = [0.0064 0.0139 0.0275 0.0488 0.1111 0.2323 0.4574 0.8905 1.0639]; % Kinectic energy (from high speed camera data): Ec = 0.5 * mass [kg] * velocity^2 [m/s]

%Labor
all_maxs_labor = cell2mat(struct2cell(load('all_maxs_labor.mat')));       %Load variable from .mat file
all_means_labor = cell2mat(struct2cell(load('all_means_labor.mat'))); 
all_std_labor = cell2mat(struct2cell(load('all_std_labor.mat')));
all_en_labor = cell2mat(struct2cell(load('all_enc_labor.mat')));

% Vallon de Nant
all_maxs_VDN = cell2mat(struct2cell(load('all_maxs_VDN.mat')));       %Load variable from .mat file
all_means_VDN = cell2mat(struct2cell(load('all_means_VDN.mat'))); 
all_std_VDN = cell2mat(struct2cell(load('all_std_VDN.mat')));
all_en_VDN = cell2mat(struct2cell(load('all_enc_VDN.mat')));

%Albula
all_maxs_Alb = cell2mat(struct2cell(load('all_maxs_Alb.mat')));       %Load variable from .mat file
all_means_Alb = cell2mat(struct2cell(load('all_means_Alb.mat'))); 
all_std_Alb = cell2mat(struct2cell(load('all_std_Alb.mat')));
all_en_Alb = cell2mat(struct2cell(load('all_enc_Alb.mat')));

%Naviscence
all_maxs_Nav = cell2mat(struct2cell(load('all_maxs_Nav.mat')));       %Load variable from .mat file
all_means_Nav = cell2mat(struct2cell(load('all_means_Nav.mat'))); 
all_std_Nav = cell2mat(struct2cell(load('all_std_Nav.mat')));
all_en_Nav = cell2mat(struct2cell(load('all_enc_Nav.mat')));

%Riedbach
all_maxs_Ried = cell2mat(struct2cell(load('all_maxs_Ried.mat')));       %Load variable from .mat file
all_means_Ried = cell2mat(struct2cell(load('all_means_Ried.mat'))); 
all_std_Ried = cell2mat(struct2cell(load('all_std_Ried.mat')));
all_en_Ried = cell2mat(struct2cell(load('all_enc_Ried.mat')));

%% Regressions

len_labor = log(Ec);
lmax_labor = log(all_means_labor);
len_VDN = log(Ec');
lmax_VDN = log(all_means_VDN);
len_Alb = log(Ec');
lmax_Alb = log(all_means_Alb);
len_Nav = log(Ec');
lmax_Nav = log(all_means_Nav);
len_Ried = log(Ec');
lmax_Ried = log(all_means_Ried);

p_labor=polyfit(len_labor,lmax_labor,1);
p_VDN=polyfit(len_VDN,lmax_VDN,1);
p_Alb=polyfit(len_Alb,lmax_Alb,1);
p_Nav=polyfit(len_Nav,lmax_Nav,1);
p_Ried=polyfit(len_Ried,lmax_Ried,1);

x_fitline_labor = len_labor;
x_fitline_VDN = len_VDN;
x_fitline_Alb = len_Alb;
x_fitline_Nav = len_Nav;
x_fitline_Ried = len_Ried;

y_fitline_labor = p_labor(1)*x_fitline_labor+p_labor(2);
y_fitline_VDN = p_VDN(1)*x_fitline_VDN+p_VDN(2);
y_fitline_Alb = p_Alb(1)*x_fitline_Alb+p_Alb(2);
y_fitline_Nav = p_Nav(1)*x_fitline_Nav+p_Nav(2);
y_fitline_Ried = p_Ried(1)*x_fitline_Ried+p_Ried(2);

x_fitlog_labor = exp(x_fitline_labor);
x_fitlog_VDN = exp(x_fitline_VDN);
x_fitlog_Alb = exp(x_fitline_Alb);
x_fitlog_Nav = exp(x_fitline_Nav);
x_fitlog_Ried = exp(x_fitline_Ried);

y_fitlog_labor = exp(y_fitline_labor);
y_fitlog_VDN = exp(y_fitline_VDN);
y_fitlog_Alb = exp(y_fitline_Alb);
y_fitlog_Nav = exp(y_fitline_Nav);
y_fitlog_Ried = exp(y_fitline_Ried);

yfit_labor = polyval(p_labor,len_labor);
yfit_VDN = polyval(p_VDN,len_VDN);
yfit_Alb = polyval(p_Alb,len_Alb);
yfit_Nav = polyval(p_Nav,len_Nav);
yfit_Ried = polyval(p_Ried,len_Ried);

yresid_labor = lmax_labor - yfit_labor;
yresid_VDN = lmax_VDN - yfit_VDN;
yresid_Alb = lmax_Alb - yfit_Alb;
yresid_Nav = lmax_Nav - yfit_Nav;
yresid_Ried = lmax_Ried - yfit_Ried;

SSresid_labor = sum(yresid_labor.^2);
SSresid_VDN = sum(yresid_VDN.^2);
SSresid_Alb = sum(yresid_Alb.^2);
SSresid_Nav = sum(yresid_Nav.^2);
SSresid_Ried = sum(yresid_Ried.^2);

SStotal_labor = (length(len_labor)-1) * var(len_labor);
SStotal_VDN = (length(len_VDN)-1) * var(len_VDN);
SStotal_Alb = (length(len_Alb)-1) * var(len_Alb);
SStotal_Nav = (length(len_Nav)-1) * var(len_Nav);
SStotal_Ried = (length(len_Ried)-1) * var(len_Ried);

rsq_labor = 1 - SSresid_labor/SStotal_labor;
rsq_VDN = 1 - SSresid_VDN/SStotal_VDN;
rsq_Alb = 1 - SSresid_Alb/SStotal_Alb;
rsq_Nav = 1 - SSresid_Nav/SStotal_Nav;
rsq_Ried = 1 - SSresid_Ried/SStotal_Ried;

